# Vuln-finder
A simple commandline app for searching and looking up opensource vulnerabilities

# Installation

## Using Pip
```bash
  $ pip install vuln-finder
```

# Usage
```bash
$ cver
```
## Search
`search <keyword>`
```bash
$ cver search python
```
## Lookup
`search <name>`
```bash
$ cver look-up CVE-2020-2121
```